import 'package:plugin_platform_interface/plugin_platform_interface.dart';

import 'buzz_booster_method_channel.dart';

abstract class BuzzBoosterPlatform extends PlatformInterface {
  /// Constructs a BuzzBoosterPlatform.
  BuzzBoosterPlatform() : super(token: _token);

  static final Object _token = Object();

  static BuzzBoosterPlatform _instance = MethodChannelBuzzBooster();

  /// The default instance of [BuzzBoosterPlatform] to use.
  ///
  /// Defaults to [MethodChannelBuzzBooster].
  static BuzzBoosterPlatform get instance => _instance;
  
  /// Platform-specific implementations should set this with their own
  /// platform-specific class that extends [BuzzBoosterPlatform] when
  /// they register themselves.
  static set instance(BuzzBoosterPlatform instance) {
    PlatformInterface.verifyToken(instance, _token);
    _instance = instance;
  }

  Future<String?> getPlatformVersion() {
    throw UnimplementedError('platformVersion() has not been implemented.');
  }

  Future<void> init(String appKey) {
    throw UnimplementedError('init() has not been implemented.');
  }

  Future<void> setUserId(String? userId) {
    throw UnimplementedError('setUserId() has not been implemented.');
  }
}
